@@ -436,6 +436,9 @@ add_open(struct daemon_remote* rc, struct nsd_options* cfg, const char* ip,
 		 */
 		if(fd != -1) {
 #ifdef HAVE_CHOWN
+			if(chmod(ip, (mode_t)(S_IRUSR | S_IWUSR | S_IRGRP | S_IWGRP)) == -1) {
+				VERBOSITY(3, (LOG_INFO, "cannot chmod control socket %s: %s", ip, strerror(errno)));
+			}
 			if (cfg->username && cfg->username[0] &&
 				nsd.uid != (uid_t)-1) {
 				if(chown(ip, nsd.uid, nsd.gid) == -1)
@@ -443,9 +446,6 @@ add_open(struct daemon_remote* rc, struct nsd_options* cfg, const char* ip,
 					  (unsigned)nsd.uid, (unsigned)nsd.gid,
 					  ip, strerror(errno)));
 			}
-			if(chmod(ip, (mode_t)(S_IRUSR | S_IWUSR | S_IRGRP | S_IWGRP)) == -1) {
-				VERBOSITY(3, (LOG_INFO, "cannot chmod control socket %s: %s", ip, strerror(errno)));
-			}
 #else
 			(void)cfg;
 #endif
@@ -2668,6 +2668,10 @@ print_stat_block(RES* ssl, char* n, char* d, struct nsdst* st)
 	if(!ssl_printf(ssl, "%s%snum.raxfr=%lu\n", n, d, (unsigned long)st->raxfr))
 		return;
 
+	/* number of requested-ixfr, number of times ixfr served to clients */
+	if(!ssl_printf(ssl, "%s%snum.rixfr=%lu\n", n, d, (unsigned long)st->rixfr))
+		return;
+
 	/* truncated */
 	if(!ssl_printf(ssl, "%s%snum.truncated=%lu\n", n, d,
 		(unsigned long)st->truncated))
